heros.zenoh - heros 0.8.1 documentation

Skip to content
Back to top
View this page

# heros.zenoh

## Attributes

`session_manager` |

## Classes

`ZenohSessionManager` |

## Module Contents

class heros.zenoh.ZenohSessionManager(config_dict: dict | None = None)
  _config_dict
  _session = None
  _referrers = []
  request_session(obj: object) → zenoh.Session

    Request the global zenoh session.

    Parameters:

      obj – The object that requests the session

  release_session(obj: object) → None

    Release from the global zenoh session.

    Parameters:

      obj – The object that wants to release from the global zenoh session

  update_config(config_dict: dict) → None
  force_close() → None

heros.zenoh.session_manager